@@ -27,6 +27,7 @@
 #include <telepathy-glib/telepathy-glib.h>
 #include "mission-control-plugins/mission-control-plugins.h"
 #include "mcd-storage.h"
+#include "connectivity-monitor.h"
 
 G_BEGIN_DECLS
 #define MCD_TYPE_ACCOUNT_MANAGER         (mcd_account_manager_get_type ())
@@ -56,18 +57,11 @@ struct _McdAccountManager
 struct _McdAccountManagerClass
 {
     GObjectClass parent_class;
-    McdAccount *(*account_new) (McdAccountManager *account_manager,
-                                const gchar *name);
-    void (*_mc_reserved2) (void);
-    void (*_mc_reserved3) (void);
-    void (*_mc_reserved4) (void);
-    void (*_mc_reserved5) (void);
-    void (*_mc_reserved6) (void);
-    void (*_mc_reserved7) (void);
 };
 
 GType mcd_account_manager_get_type (void);
-McdAccountManager *mcd_account_manager_new (TpDBusDaemon *dbus_daemon);
+McdAccountManager *mcd_account_manager_new (
+    TpSimpleClientFactory *client_factory);
 
 TpDBusDaemon *mcd_account_manager_get_dbus_daemon
     (McdAccountManager *account_manager);
@@ -88,6 +82,9 @@ McdAccount *mcd_account_manager_lookup_account_by_path (McdAccountManager *accou
 
 McdStorage *mcd_account_manager_get_storage (McdAccountManager *manager);
 
+McdConnectivityMonitor *mcd_account_manager_get_connectivity_monitor (
+    McdAccountManager *self);
+
 G_END_DECLS
 
 #endif
