@@ -23,18 +23,16 @@
  * 02110-1301 USA
  *
  */
+#include "config.h"
 
 #include <stdio.h>
 #include <string.h>
 #include <glib/gstdio.h>
-#include <config.h>
 
 #include <dbus/dbus-glib-lowlevel.h>
 
-#include <telepathy-glib/gtypes.h>
-#include <telepathy-glib/svc-channel-request.h>
-#include <telepathy-glib/svc-generic.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #include "mcd-account.h"
 #include "mcd-account-priv.h"
