@@ -58,7 +58,7 @@ static const McdInterfaceData dispatch_operation_interfaces[] = {
     MCD_IMPLEMENT_IFACE (tp_svc_channel_dispatch_operation_get_type,
                          dispatch_operation,
                          TP_IFACE_CHANNEL_DISPATCH_OPERATION),
-    { G_TYPE_INVALID, }
+    { NULL, }
 };
 
 G_DEFINE_TYPE_WITH_CODE (McdDispatchOperation, _mcd_dispatch_operation,
@@ -521,10 +521,7 @@ _mcd_dispatch_operation_check_client_locks (McdDispatchOperation *self)
     /* if we've been claimed, respond, then do not call HandleChannels */
     if (approval != NULL && approval->type == APPROVAL_TYPE_CLAIM)
     {
-        /* this needs to be copied because we don't use it til after we've
-         * freed approval->context */
-        gchar *caller = g_strdup (dbus_g_method_get_sender (
-            approval->context));
+        gchar *caller = dbus_g_method_get_sender (approval->context);
 
         /* remove this approval from the list, so it won't be treated as a
          * failure */
@@ -827,13 +824,16 @@ _mcd_dispatch_operation_finish (McdDispatchOperation *operation,
          approval != NULL;
          approval = g_queue_pop_head (priv->approvals))
     {
+        gchar *caller;
+
         switch (approval->type)
         {
             case APPROVAL_TYPE_CLAIM:
                 /* someone else got it - either another Claim() or a handler */
                 g_assert (approval->context != NULL);
-                DEBUG ("denying Claim call from %s",
-                       dbus_g_method_get_sender (approval->context));
+                caller = dbus_g_method_get_sender (approval->context);
+                DEBUG ("denying Claim call from %s", caller);
+                g_free (caller);
                 dbus_g_method_return_error (approval->context, priv->result);
                 approval->context = NULL;
                 break;
@@ -2048,15 +2048,17 @@ _mcd_dispatch_operation_run_observers (McdDispatchOperation *self)
         if (self->priv->channel != NULL)
         {
             McdChannel *channel = MCD_CHANNEL (self->priv->channel);
-            GHashTable *properties;
+            GVariant *properties;
 
-            properties = _mcd_channel_get_immutable_properties (channel);
+            properties = mcd_channel_dup_immutable_properties (channel);
             g_assert (properties != NULL);
 
             if (_mcd_client_match_filters (properties,
                 _mcd_client_proxy_get_observer_filters (client),
                 FALSE))
                 observed = TRUE;
+
+            g_variant_unref (properties);
         }
 
         /* in particular this happens if there is no channel at all */
@@ -2166,9 +2168,9 @@ _mcd_dispatch_operation_run_approvers (McdDispatchOperation *self)
         if (self->priv->channel != NULL)
         {
             McdChannel *channel = MCD_CHANNEL (self->priv->channel);
-            GHashTable *channel_properties;
+            GVariant *channel_properties;
 
-            channel_properties = _mcd_channel_get_immutable_properties (channel);
+            channel_properties = mcd_channel_dup_immutable_properties (channel);
             g_assert (channel_properties != NULL);
 
             if (_mcd_client_match_filters (channel_properties,
@@ -2177,6 +2179,8 @@ _mcd_dispatch_operation_run_approvers (McdDispatchOperation *self)
             {
                 matched = TRUE;
             }
+
+            g_variant_unref (channel_properties);
         }
 
         /* in particular, after this point, self->priv->channel can't
