@@ -21,7 +21,7 @@ import dbus
 import dbus.service
 
 from servicetest import EventPattern, tp_name_prefix, tp_path_prefix, \
-        call_async, assertEquals
+        call_async, assertEquals, assertContains
 from mctest import exec_test, create_fakecm_account, AccountManager
 import constants as cs
 
@@ -39,20 +39,17 @@ def test(q, bus, mc):
     interfaces = properties.get('Interfaces')
     supported = properties.get('SupportedAccountProperties')
 
-    # assert that current functionality exists
-    assert cs.AM_IFACE_NOKIA_QUERY in interfaces, interfaces
-
     assert (cs.ACCOUNT + '.AutomaticPresence') in supported
     assert (cs.ACCOUNT + '.Enabled') in supported
     assert (cs.ACCOUNT + '.Icon') in supported
     assert (cs.ACCOUNT + '.Nickname') in supported
     assert (cs.ACCOUNT + '.ConnectAutomatically') in supported
     assert (cs.ACCOUNT_IFACE_AVATAR + '.Avatar') in supported
-    assert (cs.ACCOUNT_IFACE_NOKIA_COMPAT + '.SecondaryVCardFields') in supported
     assert (cs.ACCOUNT_IFACE_NOKIA_CONDITIONS + '.Condition') in supported
 
     assert (cs.ACCOUNT + '.RequestedPresence') in supported
     assert (cs.ACCOUNT + '.Supersedes') in supported
+    assertContains(cs.ACCOUNT + '.Service', supported)
 
     params = dbus.Dictionary({"account": "anarki@example.com",
         "password": "secrecy"}, signature='sv')
@@ -73,14 +70,13 @@ def test(q, bus, mc):
         cs.ACCOUNT + '.ConnectAutomatically': True,
         cs.ACCOUNT_IFACE_AVATAR + '.Avatar': (dbus.ByteArray('foo'),
             'image/jpeg'),
-        cs.ACCOUNT_IFACE_NOKIA_COMPAT + '.SecondaryVCardFields':
-            dbus.Array(['x-ioquake3', 'x-quake3'], signature='s'),
         cs.ACCOUNT_IFACE_NOKIA_CONDITIONS + '.Condition':
             dbus.Dictionary({ 'has-quad-damage': ':y' }, signature='ss'),
         cs.ACCOUNT + '.Supersedes': dbus.Array([
             cs.ACCOUNT_PATH_PREFIX + 'q1/q1/Ranger',
             cs.ACCOUNT_PATH_PREFIX + 'q2/q2/Grunt',
             ], signature='o'),
+        cs.ACCOUNT + '.Service': 'arena',
         }, signature='sv')
 
     call_async(q, account_manager, 'CreateAccount',
@@ -133,15 +129,12 @@ def test(q, bus, mc):
                 cs.ACCOUNT_PATH_PREFIX + 'q2/q2/Grunt',
                 ], signature='o'),
         properties.get('Supersedes'))
+    assertEquals('arena', properties.get('Service'))
 
     properties = account_props.GetAll(cs.ACCOUNT_IFACE_AVATAR)
     assert properties.get('Avatar') == ([ord('f'), ord('o'), ord('o')],
             'image/jpeg')
 
-    properties = account_props.GetAll(cs.ACCOUNT_IFACE_NOKIA_COMPAT)
-    assert sorted(properties.get('SecondaryVCardFields')) == \
-            ['x-ioquake3', 'x-quake3']
-
     properties = account_props.GetAll(cs.ACCOUNT_IFACE_NOKIA_CONDITIONS)
     assert properties.get('Condition') == {
             'has-quad-damage': ':y',
